@@ -1,9 +1,7 @@
-import os
 from collections import defaultdict
 
 from kolekto.printer import printer, bold
 from kolekto.commands import Command
-from kolekto.db import MoviesMetadata
 
 
 class FindDuplicates(Command):
@@ -14,7 +12,7 @@ class FindDuplicates(Command):
     help = 'find duplicate movies in collection'
 
     def run(self, args, config):
-        mdb = MoviesMetadata(os.path.join(args.tree, '.kolekto', 'metadata.db'))
+        mdb = self.get_metadata_db(args.tree)
         hash_by_title = defaultdict(lambda: [])
         for movie_hash, movie in mdb.itermovies():
             hash_by_title[movie.get('title', None), movie.get('year', None)].append(movie_hash)
