@@ -9,8 +9,6 @@ from kolekto.printer import printer, bold
 from kolekto.commands import Command
 from kolekto.commands.show import show
 from kolekto.datasources import MovieDatasource
-from kolekto.movie import Movie
-from kolekto.db import MoviesMetadata
 from kolekto.exceptions import KolektoRuntimeError
 
 
@@ -24,12 +22,63 @@ def clean_title(title):
         return year, title
 
 
-class Import(Command):
+def copy(tree, source_filename):
+    """ Copy file in tree, show a progress bar during operations,
+        and return the sha1 sum of copied file.
+    """
+    #_, ext = os.path.splitext(source_filename)
+    filehash = sha1()
+    with printer.progress(os.path.getsize(source_filename)) as update:
+        with open(source_filename, 'rb') as fsource:
+            with NamedTemporaryFile(dir=os.path.join(tree, '.kolekto', 'movies'), delete=False) as fdestination:
+                # Copy the source into the temporary destination:
+                while True:
+                    buf = fsource.read(10 * 1024)
+                    if not buf:
+                        break
+                    filehash.update(buf)
+                    fdestination.write(buf)
+                    update(len(buf))
+                # Rename the file to its final name or raise an error if
+                # the file already exists:
+                dest = os.path.join(tree, '.kolekto', 'movies', filehash.hexdigest())
+                if os.path.exists(dest):
+                    raise IOError('This file already exists in tree (%s)' % filehash.hexdigest())
+                else:
+                    os.rename(fdestination.name, dest)
+    return filehash.hexdigest()
 
-    """ Import movies into the Kolekto tree.
+
+def link(tree, source_filename, symlink=False):
+    filehash = sha1()
+    with printer.progress(os.path.getsize(source_filename)) as update:
+        with open(source_filename, 'rb') as fsource:
+                # Copy the source into the temporary destination:
+                while True:
+                    buf = fsource.read(10 * 1024)
+                    if not buf:
+                        break
+                    filehash.update(buf)
+                    update(len(buf))
+                # Hardlink the file or raise an error if the file already exists:
+                dest = os.path.join(tree, '.kolekto', 'movies', filehash.hexdigest())
+                if os.path.exists(dest):
+                    raise IOError('This file already exists in tree (%s)' % filehash.hexdigest())
+                else:
+                    if symlink:
+                        source_filename = os.path.relpath(source_filename,
+                                                          os.path.join(tree, '.kolekto', 'movies'))
+                        os.symlink(source_filename, dest)
+                    else:
+                        os.link(source_filename, dest)
+    return filehash.hexdigest()
+
+
+class BaseImport(Command):
+
+    """ Base class for importers.
     """
 
-    help = 'import a movie'
 
     def prepare(self):
         self.add_arg('file', nargs='+', help='Files to import (globbing allowed)')
@@ -52,63 +101,26 @@ class Import(Command):
             raise KolektoRuntimeError('--symlink and --hardlink are mutually exclusive')
 
         # Load the metadata database:
-        mdb = MoviesMetadata(os.path.join(args.tree, '.kolekto', 'metadata.db'))
+        mdb = self.get_metadata_db(args.tree)
 
         # Load informations from db:
-        mds = MovieDatasource(config.subsections('datasource'), args.tree)
+        mds = MovieDatasource(config.subsections('datasource'), args.tree, self.profile.object_class)
 
         for pattern in args.file:
             for filename in glob(pattern):
                 filename = filename.decode('utf8')
                 self._import(mdb, mds, args, config, filename)
 
-    def _copy(self, tree, source_filename):
-        """ Copy file in tree, show a progress bar during operations,
-            and return the sha1 sum of copied file.
-        """
-        #_, ext = os.path.splitext(source_filename)
-        filehash = sha1()
-        with printer.progress(os.path.getsize(source_filename)) as update:
-            with open(source_filename, 'rb') as fsource:
-                with NamedTemporaryFile(dir=os.path.join(tree, '.kolekto', 'movies'), delete=False) as fdestination:
-                    # Copy the source into the temporary destination:
-                    while True:
-                        buf = fsource.read(10 * 1024)
-                        if not buf:
-                            break
-                        filehash.update(buf)
-                        fdestination.write(buf)
-                        update(len(buf))
-                    # Rename the file to its final name or raise an error if
-                    # the file already exists:
-                    dest = os.path.join(tree, '.kolekto', 'movies', filehash.hexdigest())
-                    if os.path.exists(dest):
-                        raise IOError('This file already exists in tree (%s)' % filehash.hexdigest())
-                    else:
-                        os.rename(fdestination.name, dest)
-        return filehash.hexdigest()
+    def _import(self):
+        raise NotImplementedError()
 
-    def _link(self, tree, source_filename, symlink=False):
-        filehash = sha1()
-        with printer.progress(os.path.getsize(source_filename)) as update:
-            with open(source_filename, 'rb') as fsource:
-                    # Copy the source into the temporary destination:
-                    while True:
-                        buf = fsource.read(10 * 1024)
-                        if not buf:
-                            break
-                        filehash.update(buf)
-                        update(len(buf))
-                    # Hardlink the file or raise an error if the file already exists:
-                    dest = os.path.join(tree, '.kolekto', 'movies', filehash.hexdigest())
-                    if os.path.exists(dest):
-                        raise IOError('This file already exists in tree (%s)' % filehash.hexdigest())
-                    else:
-                        if symlink:
-                            os.symlink(source_filename, dest)
-                        else:
-                            os.link(source_filename, dest)
-        return filehash.hexdigest()
+
+class ImportMovies(BaseImport):
+
+    """ Import movies into the Kolekto tree.
+    """
+
+    help = 'import a movie'
 
     def _import(self, mdb, mds, args, config, filename):
         printer.debug('Importing file {filename}', filename=filename)
@@ -127,7 +139,7 @@ class Import(Command):
                 title = printer.input(u'Title to search', default=title)
             datasource, movie = self._search(mds, title, short_filename, year, auto=args.auto)
             if datasource == 'manual':
-                movie = Movie()
+                movie = self.profile.object_class
             elif datasource == 'abort':
                 printer.p('Aborted import of {filename}', filename=filename)
                 return
@@ -145,15 +157,15 @@ class Import(Command):
 
         # Edit available data:
         if not args.auto and printer.ask('Do you want to edit the movie metadata', default=False):
-            movie = Movie(json.loads(printer.edit(json.dumps(movie, indent=True))))
+            movie = self.profile.object_class(json.loads(printer.edit(json.dumps(movie, indent=True))))
 
         # Hardlink or copy the movie in the tree
         if args.hardlink or args.symlink:
             printer.p('\nComputing movie sha1sum...')
-            movie_hash = self._link(args.tree, filename, args.symlink)
+            movie_hash = link(args.tree, filename, args.symlink)
         else:
             printer.p('\nCopying movie in kolekto tree...')
-            movie_hash = self._copy(args.tree, filename)
+            movie_hash = copy(args.tree, filename)
         printer.p('')
 
         mdb.save(movie_hash, movie)
@@ -170,7 +182,7 @@ class Import(Command):
         If auto is enabled, directly returns the first movie found.
         """
         choices = []
-        for datasource, movie in mdb.search(query, year):
+        for datasource, movie in mdb.search(query, year=year):
             if auto:
                 return datasource, movie
             if movie.get('directors'):
