@@ -1,9 +1,7 @@
-import os
 import json
 
 from kolekto.printer import printer
 from kolekto.commands import Command
-from kolekto.db import MoviesMetadata
 
 
 class Restore(Command):
@@ -17,7 +15,7 @@ class Restore(Command):
         self.add_arg('file', help='The json dump file to restore')
 
     def run(self, args, config):
-        mdb = MoviesMetadata(os.path.join(args.tree, '.kolekto', 'metadata.db'))
+        mdb = self.get_metadata_db(args.tree)
         with open(args.file) as fdump:
             dump = json.load(fdump)
         for movie in dump:
